@@ -1126,11 +1126,11 @@ Options -Indexes
         $path = "/home/{$user}/public_html";
         $htaccessPath = "{$path}/.htaccess";
         
-        // Append rules to .htaccess
+        // Use cat with here-document for multi-line content
         $cmd = sprintf(
-            "echo %s >> %s",
-            escapeshellarg($rules),
-            escapeshellarg($htaccessPath)
+            "cat >> %s << 'EOF'\n%s\nEOF",
+            escapeshellarg($htaccessPath),
+            $rules
         );
         
         $result = $this->execWpCli($container, $user, $cmd, $path);
